@@ -618,6 +618,8 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 	
 	def add_block(self):
 		self.ui.blocks.addItem(self.ui.blockcombo.currentText())
+		self.ui.blocks.setCurrentRow(int(self.ui.blocks.count()) - 1)
+		self.edit_block()
 
 	def remove_block(self):
 		i = self.ui.blocks.currentRow()
